@@ -27,7 +27,7 @@ pub fn home() -> Result<PathBuf> {
     dirs::home_dir().context("$HOME was not set")
 }
 
-// clone git reposiotry into temp using libgit2
+// clone git repository into temp using libgit2
 pub fn clone_git_template_into_temp(
     git: &str,
     branch: Option<&str>,
@@ -46,15 +46,21 @@ pub fn clone_git_template_into_temp(
     if let Some(tag) = tag {
         let (object, reference) = repo.revparse_ext(tag)?;
         repo.checkout_tree(&object, None)?;
-        match reference {
-            Some(gref) => repo.set_head(gref.name().unwrap()),
-            None => repo.set_head_detached(object.id()),
-        }?;
+        reference.map_or_else(
+            || repo.set_head_detached(object.id()),
+            |gref| repo.set_head(gref.name().unwrap()),
+        )?
     }
 
     Ok((git_clone_dir, branch))
 }
 
+pub fn try_get_branch_from_path(git: impl AsRef<Path>) -> Option<String> {
+    Repository::open(git)
+        .ok()
+        .and_then(|repo| get_branch_name_repo(&repo).ok())
+}
+
 /// thanks to @extrawurst for pointing this out
 /// <https://github.com/extrawurst/gitui/blob/master/asyncgit/src/sync/branch/mod.rs#L38>
 fn get_branch_name_repo(repo: &Repository) -> anyhow::Result<String> {
