@@ -90,15 +90,14 @@ fn handle_string_input(
             }
         }
         None => {
+            let default = entry.default.as_ref().map(|v| v.to_owned());
             let prompt = format!(
-                "{} {}",
-                prompt,
-                match &entry.default {
-                    Some(d) => format!("[default: {}]", style(d).bold()),
-                    None => "".into(),
-                }
+                "{prompt}{}",
+                default
+                    .as_ref()
+                    .map(|default| format!(" [default: {}]", style(default).bold()))
+                    .unwrap_or_else(|| "".to_owned())
             );
-            let default = entry.default.as_ref().map(|v| v.into());
 
             match &entry.regex {
                 Some(regex) => loop {
@@ -176,7 +175,7 @@ fn handle_bool_input(
             let chosen = Select::with_theme(&ColorfulTheme::default())
                 .items(&choices)
                 .with_prompt(prompt)
-                .default(if default.unwrap_or(false) { 1 } else { 0 })
+                .default(usize::from(default.unwrap_or(false)))
                 .interact()?;
 
             Ok(choices.index(chosen).to_string())
