@@ -27,7 +27,7 @@ fn it_substitutes_filename() {
         .arg(template.path())
         .arg("--name")
         .arg("foobar-project")
-        .current_dir(&dir.path())
+        .current_dir(dir.path())
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").from_utf8());
@@ -36,16 +36,20 @@ fn it_substitutes_filename() {
         dir.exists("foobar-project/main.rs"),
         "project should contain foobar-project/main.rs"
     );
+    assert!(
+        !dir.exists("foobar-project/{{project-name}}.rs"),
+        "project should NOT contain foobar-project/{{project-name}}.rs"
+    );
     assert!(
         dir.exists("foobar-project/foobar-project.rs"),
         "project should contain foobar-project/foobar-project.rs"
     );
+    assert!(
+        !dir.exists("foobar-project/src/{{project-name}}/lib.rs"),
+        "project should NOT contain foobar-project/src/foobar-project/lib.rs.liquid"
+    );
     assert!(
         dir.exists("foobar-project/src/foobar-project/lib.rs"),
         "project should contain foobar-project/src/foobar-project/lib.rs"
     );
-    assert!(
-        !dir.exists("foobar-project/src/{{project-name}}/lib.rs"),
-        "project should not contain foobar-project/src/foobar-project/lib.rs.liquid"
-    );
 }
