@@ -1,9 +1,8 @@
 use assert_cmd::prelude::*;
+use bstr::ByteSlice;
 use git2::Repository;
-use git_config::parser::Key;
 use git_config::File as GitConfig;
 use predicates::prelude::*;
-use std::borrow::Cow;
 use std::ops::Deref;
 
 use crate::helpers::project::binary;
@@ -22,7 +21,7 @@ fn it_allows_a_git_branch_to_be_specified() {
         .arg(template.path())
         .arg("--name")
         .arg("foobar-project")
-        .current_dir(&dir.path())
+        .current_dir(dir.path())
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").from_utf8());
@@ -45,7 +44,7 @@ fn it_allows_a_git_tag_to_be_specified() {
         .arg(template.path())
         .arg("--name")
         .arg("foobar-project")
-        .current_dir(&dir.path())
+        .current_dir(dir.path())
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").from_utf8());
@@ -66,7 +65,7 @@ fn it_removes_git_history() {
         .arg(template.path())
         .arg("--name")
         .arg("foobar-project")
-        .current_dir(&dir.path())
+        .current_dir(dir.path())
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").from_utf8());
@@ -87,7 +86,7 @@ fn it_removes_git_history_also_on_local_templates() {
         .arg(template.path())
         .arg("--name")
         .arg("xyz")
-        .current_dir(&dir.path())
+        .current_dir(dir.path())
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").from_utf8());
@@ -109,7 +108,7 @@ fn it_should_init_an_empty_git_repo_even_when_starting_from_a_repo_when_forced()
         .arg(template.path())
         .arg("--name")
         .arg("foo")
-        .current_dir(&target_path)
+        .current_dir(target_path)
         .assert()
         .success()
         .stdout(predicates::str::contains("Done!").from_utf8());
@@ -127,17 +126,11 @@ fn should_retrieve_an_instead_of_url() {
 "#;
     let mut config = GitConfig::try_from(input).unwrap();
     let url = config
-        .value::<Cow<[u8]>>("url", Some("ssh://git@github.com:"), "insteadOf")
-        .map(|v| String::from_utf8_lossy(v.as_ref()).to_string())
+        .string("url", Some("ssh://git@github.com:"), "insteadOf")
         .unwrap();
-    assert_eq!(url, "https://github.com/");
+    assert_eq!(url.deref(), "https://github.com/");
     config
-        .set_raw_value(
-            "url",
-            Some("ssh://git@github.com:"),
-            "insteadOf",
-            "foo".as_bytes().to_vec(),
-        )
+        .set_raw_value("url", Some("ssh://git@github.com:"), "insteadOf", "foo")
         .unwrap();
 }
 
@@ -150,25 +143,23 @@ fn should_find_them_all() {
     insteadOf = https://bitbucket.org/
 "#;
     let config = GitConfig::try_from(input).unwrap();
-    let url = config.sections_by_name_with_header("url");
-    assert_eq!(url.len(), 2);
+    let url = config.sections_by_name("url").unwrap();
+    assert_eq!(config.sections_by_name("url").unwrap().count(), 2);
 
-    for (head, body) in url.iter() {
-        let url = head.subsection_name.as_ref().unwrap();
+    for section in url {
+        let head = section.header();
+        let body = section.body();
 
-        let instead_of = body.value(&Key::from("insteadOf"));
-        if url.contains("github") {
+        let url = head.subsection_name().as_ref().unwrap().to_str().unwrap();
+
+        let instead_of_value = body.value("insteadOf").unwrap();
+        let instead_of = instead_of_value.to_str().unwrap();
+        if instead_of.contains("github") {
             assert_eq!(url, "ssh://git@github.com:");
-            assert_eq!(
-                instead_of.unwrap().deref(),
-                "https://github.com/".as_bytes()
-            )
+            assert_eq!(instead_of, "https://github.com/")
         } else {
             assert_eq!(url, "ssh://git@bitbucket.org:");
-            assert_eq!(
-                instead_of.unwrap().as_ref(),
-                "https://bitbucket.org/".as_bytes()
-            )
+            assert_eq!(instead_of, "https://bitbucket.org/")
         }
     }
 }
